@@ -432,21 +432,25 @@ func validateBuiltImageVersion(r command.Runner, driverName string) {
 }
 
 func imageMatchesBinaryVersion(imageVersion, binaryVersion string) bool {
+	if binaryVersion == imageVersion {
+		return true
+	}
+
 	// the map below is used to map the binary version to the version the image expects
 	// this is usually done when a patch version is released but a new ISO/Kicbase is not needed
 	// that way a version mismatch warning won't be thrown
 	//
 	// ex.
 	// the v1.31.0 and v1.31.1 minikube binaries both use v1.31.0 ISO & Kicbase
-	// to prevent the v1.31.1 binary from throwing a version mismatch warning we use the map to use change the binary version used in the comparison
+	// to prevent the v1.31.1 binary from throwing a version mismatch warning we use the map to change the binary version used in the comparison
 
 	mappedVersions := map[string]string{
 		"v1.31.1": "v1.31.0",
+		"v1.31.2": "v1.31.0",
 	}
-	if v, ok := mappedVersions[binaryVersion]; ok {
-		binaryVersion = v
-	}
-	return binaryVersion == imageVersion
+	binaryVersion, ok := mappedVersions[binaryVersion]
+
+	return ok && binaryVersion == imageVersion
 }
 
 func startWithDriver(cmd *cobra.Command, starter node.Starter, existing *config.ClusterConfig) (*kubeconfig.Settings, error) {
@@ -1845,7 +1849,7 @@ func validateDockerStorageDriver(drvName string) {
 	if si.StorageDriver == "overlay2" {
 		return
 	}
-	out.WarningT("{{.Driver}} is currently using the {{.StorageDriver}} storage driver, consider switching to overlay2 for better performance", out.V{"StorageDriver": si.StorageDriver, "Driver": drvName})
+	out.WarningT("{{.Driver}} is currently using the {{.StorageDriver}} storage driver, setting preload=false", out.V{"StorageDriver": si.StorageDriver, "Driver": drvName})
 	viper.Set(preload, false)
 }
 
