@@ -600,7 +600,7 @@ Alternatively, you can try upgrading to the latest hyperkit version, or using an
 		Kind: Kind{
 			ID:       "PR_QEMU_SOCKET_VMNET_DENIED",
 			ExitCode: ExProviderError,
-			Advice:   "socket_vmnet was installed with an incorrect group, delete this cluster 'minikube delete' and update the group 'sudo chown root:$(stat -f \"%Sg\" ~) /var/run/socket_vmnet' and try again.",
+			Advice:   "socket_vmnet was installed with an incorrect group, delete this cluster 'minikube delete' and update the group 'sudo chown root:$(id -ng) /var/run/socket_vmnet' and try again.",
 		},
 		Regexp: re(`Failed to connect to "/var/run/socket_vmnet": Permission denied`),
 	},
@@ -674,7 +674,7 @@ var driverIssues = []match{
 			ID:       "DRV_HYPERV_NO_VSWITCH",
 			ExitCode: ExDriverConfig,
 			Advice:   "Configure an external network switch following the official documentation, then add `--hyperv-virtual-switch=<switch-name>` to `minikube start`",
-			URL:      "https://docs.docker.com/machine/drivers/hyper-v/",
+			URL:      "https://minikube.sigs.k8s.io/docs/reference/drivers/hyperv/",
 		},
 		Regexp: re(`no External vswitch found. A valid vswitch must be available for this command to run.`),
 		GOOS:   []string{"windows"},
@@ -684,7 +684,7 @@ var driverIssues = []match{
 			ID:       "DRV_HYPERV_VSWITCH_NOT_FOUND",
 			ExitCode: ExDriverUsage,
 			Advice:   "Confirm that you have supplied the correct value to --hyperv-virtual-switch using the 'Get-VMSwitch' command",
-			URL:      "https://docs.docker.com/machine/drivers/hyper-v/",
+			URL:      "https://minikube.sigs.k8s.io/docs/reference/drivers/hyperv/",
 		},
 		Regexp: re(`precreate: vswitch.*not found`),
 		GOOS:   []string{"windows"},
@@ -694,7 +694,7 @@ var driverIssues = []match{
 			ID:       "DRV_HYPERV_POWERSHELL_NOT_FOUND",
 			ExitCode: ExDriverUnavailable,
 			Advice:   "To start minikube with Hyper-V, Powershell must be in your PATH`",
-			URL:      "https://docs.docker.com/machine/drivers/hyper-v/",
+			URL:      "https://minikube.sigs.k8s.io/docs/reference/drivers/hyperv/",
 		},
 		Regexp: re(`Powershell was not found in the path`),
 		GOOS:   []string{"windows"},
@@ -1037,7 +1037,7 @@ var guestIssues = []match{
 			ID:       "GUEST_FILE_IN_USE",
 			ExitCode: ExGuestConflict,
 			Advice:   "Another program is using a file required by minikube. If you are using Hyper-V, try stopping the minikube VM from within the Hyper-V manager",
-			URL:      "https://docs.docker.com/machine/drivers/hyper-v/",
+			URL:      "https://minikube.sigs.k8s.io/docs/reference/drivers/hyperv/",
 			Issues:   []int{7300},
 		},
 		Regexp: re(`The process cannot access the file because it is being used by another process`),
